/*
 * VerletWeis 
 * Copyright 2004 Giuseppe Foffi & Gavin McCullagh 
 * www_gmc@fiachra.ucd.ie
 */
/*
 * This file is part of VerletWeis.
 * VerletWeis is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * VerletWeis is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Foobar; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

#include <vector>
#include <unistd.h>
#include "verletweis.h"


/*
 * Usage
 */
void usage(int argc, char **argv)
{
  cout  
    << "Prints g(r) for the Verlet-Weis Hard Sphere Fluid Theory. Format: r g(r) " << endl
    << "The defaults produce data which compare to Theory of Simple Liquids (Hansen,McDonald) p125." << endl
    << "Usage : getVerletWeisGR" << endl
    << "\t [-i initial r] Def: 0.0" << endl
    << "\t [-d delta r ] Def: 0.01" << endl
    << "\t [-f final r] Def: 2.75" << endl
    << "\t [-p packing fraction] Def: 0.49" << endl
    << "\t [-P 1 or 0, whether to include Perkus Yevick for comparison] Def: 0 (false)" << endl
    << "\t [-s sigma] Def: 1" << endl
    << "\t [-h ] prints this help message" << endl
    ;
}

/*
 * Process the command line Options
 */
void readCommandLineOptions(int argc, char **argv, 
    double& phi, double& r_init, double& r_delta, double& r_final, double& sigma, int& py) 
{
  if(argc > 1) {
    int c;
    // print options back to command line
    //for(int i = 0; i < argc; ++i) cout << i << " " << argv[i] << endl;

    // loop over options
    while( (c = getopt(argc, argv, "d:i:f:p:P:s:h:") ) != EOF) {

      switch(c) {
        case 'd':
          r_delta = atof(optarg);
          break;
        case 'i':
          r_init = atof(optarg);
          break;
        case 'f':
          r_final = atof(optarg);
          break;
        case 'p':
          phi = atof(optarg);
          break;
        case 'P':
          py = atoi(optarg);
          break;
        case 's':
          sigma = atof(optarg);
          break;
        case 'h':
          usage(argc, argv);
          break;
        default:
          usage(argc, argv);
          exit(1);
      }
    }
  }
}

/*
 * Simple main function
 */

int main(int argc, char **argv) 
{

  double phi(0.49), R_start(0.0), R_finish(2.75), R_delta(0.01), sigma(1);
  int i(0), py(0);
 
  readCommandLineOptions(argc,argv,phi,R_start,R_delta,R_finish,sigma,py);

  VerletWeis* myVW = new VerletWeis(phi,R_start,R_finish,R_delta,sigma);

  // this is just quick 'n' dirty, sorry.
  if(py == 1) {
    vector<double> r, vwgr, pygr;
    myVW->getPYVWGvector(r,vwgr,pygr);
    cout << "# r g(r)_vw g(r)_py" << endl;
    double imax = r.size();
    for(i=0;  i< imax; i++) {
      cout << r[i] << " " << vwgr[i] << " " << pygr[i] << endl;
    }
  }
  else {
    vector<double> r, vwgr;
    myVW->getVWGvector(r,vwgr);
    cout << "# r g(r)" << endl;
    double imax = r.size();
    for(i=0;  i< imax; i++) {
      cout << r[i] << " " << vwgr[i] << endl;
    }
  }

}

