/*
 * VerletWeis 
 * Copyright 2004 Giuseppe Foffi & Gavin McCullagh 
 * www_gmc@fiachra.ucd.ie
 */
/*
 * This file is part of VerletWeis.
 * VerletWeis is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * VerletWeis is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with VerletWeis; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */
#ifndef _VerletWeis_h_
#define _VerletWeis_h_

#include <cmath>
#include <iostream>
#include <stdio.h>
#include <vector>
#include <complex>

using namespace std;

class VerletWeis
{

  public:
    VerletWeis(double eta, double R_start, double R_finish, double R_delta, double sigma);
    int getVWGvector(vector<double> &r, vector<double> &gr);
    int getPYVWGvector(vector<double> &r, vector<double> &vwgr, vector<double> &pygr);

  private:
    double eta, R_start, R_finish, R_delta, sigma;
    
    double Heavi(const double &x);
    void Spoles(const double & p, vector< complex <double> > & poles); 
    complex <double> G_1(const double& r, const double& p) ;
    complex <double> G_2(const double& r, const double& p);
    complex<double> L(const double & p, const complex<double>& t);
    double Lprime(const double & p, const complex <double>& t); 

    double g_radial(double r, double p) ;

    double Integrate(double *func, int nu, double mesh);

    double Integrate(const vector<double>& func, const int& nu, const double& mesh);

    int Solve3(const vector<double> & a, vector< complex<double> > & sol);
    int Solve3(const vector<double> & a, vector <double> & sol);
    complex<double> getTerm(const vector<double> &a);
    complex<double> getSquareroo(const vector<double> &a);
    double g_radial_verlet(const double& r, const double& phi);
    double deltaG(const double &r, const double &p);
    double A( const double& e) ;
    double alpha( const double& e ) ;

};
#endif
